==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/bs/chinese.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "sada",
	"field-quarter-relative+-1": "posljednji kvartal",
	"field-weekday": "dan u sedmici",
	"field-mon-narrow-relative+0": "ovaj pon.",
	"field-mon-narrow-relative+1": "sljedeći pon",
	"field-wed-relative+0": "ova srijeda",
	"field-wed-relative+1": "sljedeća srijeda",
	"field-week-short": "sed.",
	"field-tue-relative+-1": "prošli utorak",
	"field-year-short": "god.",
	"field-thu-narrow-relative+-1": "prošli čet.",
	"field-hour-relative+0": "ovaj sat",
	"field-quarter-narrow": "kv.",
	"field-fri-relative+-1": "prošli petak",
	"field-hour-short": "h",
	"field-wed-relative+-1": "prošla srijeda",
	"field-mon-short-relative+-1": "prošli pon.",
	"field-thu-relative+-1": "prošli četvrtak",
	"field-era": "era",
	"field-sat-narrow-relative+0": "ova sub.",
	"field-sat-narrow-relative+1": "sljedeća sub.",
	"field-year": "godina",
	"field-hour": "sat",
	"field-sat-relative+0": "ova subota",
	"field-sat-relative+1": "sljedeća subota",
	"field-sat-short-relative+-1": "prošla sub.",
	"field-minute-narrow": "min.",
	"field-day-relative+0": "danas",
	"field-day-relative+1": "sutra",
	"field-thu-relative+0": "ovaj četvrtak",
	"field-wed-narrow-relative+0": "ova sri.",
	"field-mon-narrow-relative+-1": "prošli pon.",
	"field-day-relative+2": "prekosutra",
	"field-thu-relative+1": "sljedeći četvrtak",
	"field-wed-narrow-relative+1": "sljedeća sri.",
	"field-mon-short-relative+0": "ovaj pon.",
	"field-mon-short-relative+1": "sljedeći pon",
	"field-wed-short-relative+-1": "prošla sri.",
	"field-fri-narrow-relative+-1": "prošli pet.",
	"field-hour-narrow": "h",
	"field-tue-short-relative+0": "ovaj uto.",
	"field-year-narrow": "g.",
	"field-tue-short-relative+1": "sljedeći uto.",
	"field-minute-short": "min.",
	"field-day-narrow": "dan",
	"field-wed-short-relative+0": "ova sri.",
	"field-wed-short-relative+1": "sljedeća sri.",
	"field-sun-relative+0": "ova nedjelja",
	"field-sun-relative+1": "sljedeća nedjelja",
	"field-minute": "minuta",
	"field-month-short": "mj.",
	"field-dayperiod": "prijepodne/poslijepodne",
	"field-day-relative+-1": "jučer",
	"field-day-relative+-2": "prekjučer",
	"field-minute-relative+0": "ova minuta",
	"field-week-narrow": "sed.",
	"field-wed-narrow-relative+-1": "prošla sri.",
	"field-day-short": "dan",
	"field-quarter-relative+0": "ovaj kvartal",
	"field-quarter-relative+1": "sljedeći kvartal",
	"field-fri-relative+0": "ovaj petak",
	"field-fri-relative+1": "sljedeći petak",
	"field-day": "dan",
	"field-second-narrow": "s",
	"field-zone": "vremenska zona",
	"field-year-relative+-1": "prošle godine",
	"field-month-relative+-1": "prošli mjesec",
	"field-thu-short-relative+0": "ovaj čet.",
	"field-thu-short-relative+1": "sljedeći čet.",
	"field-quarter": "kvartal",
	"field-month": "mjesec",
	"field-tue-relative+0": "ovaj utorak",
	"field-tue-relative+1": "sljedeći utorak",
	"field-fri-narrow-relative+0": "ovaj pet.",
	"field-fri-narrow-relative+1": "sljedeći pet.",
	"field-fri-short-relative+-1": "prošli pet.",
	"field-sun-narrow-relative+-1": "prošla ned.",
	"field-sun-narrow-relative+0": "ova ned.",
	"field-thu-narrow-relative+0": "ovaj čet.",
	"field-sun-narrow-relative+1": "sljedeća ned.",
	"field-thu-narrow-relative+1": "sljedeći čet.",
	"field-tue-narrow-relative+0": "ovaj uto.",
	"field-mon-relative+0": "ovaj ponedjeljak",
	"field-tue-narrow-relative+1": "sljedeći uto.",
	"field-mon-relative+1": "sljedeći ponedjeljak",
	"field-tue-narrow-relative+-1": "prošli uto.",
	"field-second-short": "sek.",
	"field-second": "sekunda",
	"field-fri-short-relative+0": "ovaj pet.",
	"field-sat-relative+-1": "prošla subota",
	"field-fri-short-relative+1": "sljedeći pet.",
	"field-sun-relative+-1": "prošla nedjelja",
	"field-month-relative+0": "ovaj mjesec",
	"field-month-relative+1": "sljedeći mjesec",
	"field-week": "sedmica",
	"field-sat-short-relative+0": "ova sub.",
	"field-sat-short-relative+1": "sljedeća sub.",
	"field-year-relative+0": "ove godine",
	"field-week-relative+-1": "prošle sedmice",
	"field-year-relative+1": "sljedeće godine",
	"field-quarter-short": "kv.",
	"field-sun-short-relative+-1": "prošla ned.",
	"field-thu-short-relative+-1": "prošli čet.",
	"field-tue-short-relative+-1": "prošli uto.",
	"field-mon-relative+-1": "prošli ponedjeljak",
	"field-sat-narrow-relative+-1": "prošla sub.",
	"field-month-narrow": "mj.",
	"field-week-relative+0": "ove sedmice",
	"field-sun-short-relative+0": "ova ned.",
	"field-week-relative+1": "sljedeće sedmice",
	"field-sun-short-relative+1": "sljedeća ned."
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/bs/chinese.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "sada",
	"field-quarter-relative+-1": "posljednji kvartal",
	"field-weekday": "dan u sedmici",
	"field-mon-narrow-relative+0": "ovaj pon.",
	"field-mon-narrow-relative+1": "sljedeći pon.",
	"field-weekOfMonth-short": "sed. u mj.",
	"field-weekday-short": "dan u sed.",
	"field-wed-relative+0": "ova srijeda",
	"field-wed-relative+1": "sljedeća srijeda",
	"field-dayperiod-short": "prijepodne/poslijepodne",
	"field-week-short": "sed.",
	"field-tue-relative+-1": "prošli utorak",
	"field-year-short": "god.",
	"field-era-narrow": "era",
	"field-thu-narrow-relative+-1": "prošli čet.",
	"field-hour-relative+0": "ovaj sat",
	"field-quarter-narrow": "kv.",
	"field-fri-relative+-1": "prošli petak",
	"field-hour-short": "h",
	"field-wed-relative+-1": "prošla srijeda",
	"field-dayOfYear": "dan u godini",
	"field-mon-short-relative+-1": "prošli pon.",
	"field-thu-relative+-1": "prošli četvrtak",
	"field-era": "era",
	"field-sat-narrow-relative+0": "ova sub.",
	"field-sat-narrow-relative+1": "sljedeća sub.",
	"field-year": "godina",
	"field-hour": "sat",
	"field-sat-relative+0": "ova subota",
	"field-sat-relative+1": "sljedeća subota",
	"field-sat-short-relative+-1": "prošla sub.",
	"field-weekOfMonth-narrow": "s. u mj.",
	"field-minute-narrow": "min.",
	"field-day-relative+0": "danas",
	"field-day-relative+1": "sutra",
	"field-thu-relative+0": "ovaj četvrtak",
	"field-mon-narrow-relative+-1": "prošli pon.",
	"field-day-relative+2": "prekosutra",
	"field-wed-narrow-relative+0": "ova sri.",
	"field-thu-relative+1": "sljedeći četvrtak",
	"field-wed-narrow-relative+1": "sljedeća sri.",
	"field-mon-short-relative+0": "ovaj pon.",
	"field-mon-short-relative+1": "sljedeći pon",
	"field-weekdayOfMonth-short": "dan u mj.",
	"field-wed-short-relative+-1": "prošla sri.",
	"field-fri-narrow-relative+-1": "prošli pet.",
	"field-hour-narrow": "h",
	"field-tue-short-relative+0": "ovaj uto.",
	"field-year-narrow": "g.",
	"field-tue-short-relative+1": "sljedeći uto.",
	"field-minute-short": "min.",
	"field-day-narrow": "dan",
	"field-wed-short-relative+0": "ova sri.",
	"field-wed-short-relative+1": "sljedeća sri.",
	"field-sun-relative+0": "ova nedjelja",
	"field-sun-relative+1": "sljedeća nedjelja",
	"field-minute": "minuta",
	"field-month-short": "mj.",
	"field-dayperiod": "prijepodne/poslijepodne",
	"field-weekdayOfMonth-narrow": "d. u mj.",
	"field-day-relative+-1": "jučer",
	"field-day-relative+-2": "prekjučer",
	"field-minute-relative+0": "ova minuta",
	"field-week-narrow": "sed.",
	"field-wed-narrow-relative+-1": "prošla sri.",
	"field-day-short": "dan",
	"field-quarter-relative+0": "ovaj kvartal",
	"field-dayperiod-narrow": "prijepodne/poslijepodne",
	"field-quarter-relative+1": "sljedeći kvartal",
	"field-zone-short": "zona",
	"field-fri-relative+0": "ovaj petak",
	"field-fri-relative+1": "sljedeći petak",
	"field-day": "dan",
	"field-second-narrow": "s",
	"field-zone": "vremenska zona",
	"field-year-relative+-1": "prošle godine",
	"field-month-relative+-1": "prošli mjesec",
	"field-thu-short-relative+0": "ovaj čet.",
	"field-thu-short-relative+1": "sljedeći čet.",
	"field-weekday-narrow": "dan u sed.",
	"field-quarter": "kvartal",
	"field-zone-narrow": "zona",
	"field-month": "mjesec",
	"field-weekOfMonth": "sedmica u mjesecu",
	"field-tue-relative+0": "ovaj utorak",
	"field-tue-relative+1": "sljedeći utorak",
	"field-fri-narrow-relative+0": "ovaj pet.",
	"field-fri-narrow-relative+1": "sljedeći pet.",
	"field-fri-short-relative+-1": "prošli pet.",
	"field-sun-narrow-relative+-1": "prošla ned.",
	"field-dayOfYear-short": "dan u god.",
	"field-sun-narrow-relative+0": "ova ned.",
	"field-thu-narrow-relative+0": "ovaj čet.",
	"field-sun-narrow-relative+1": "sljedeća ned.",
	"field-thu-narrow-relative+1": "sljedeći čet.",
	"field-tue-narrow-relative+0": "ovaj uto.",
	"field-mon-relative+0": "ovaj ponedjeljak",
	"field-tue-narrow-relative+1": "sljedeći uto.",
	"field-mon-relative+1": "sljedeći ponedjeljak",
	"field-tue-narrow-relative+-1": "prošli uto.",
	"field-second-short": "sek.",
	"field-second": "sekunda",
	"field-fri-short-relative+0": "ovaj pet.",
	"field-sat-relative+-1": "prošla subota",
	"field-fri-short-relative+1": "sljedeći pet.",
	"field-sun-relative+-1": "prošla nedjelja",
	"field-month-relative+0": "ovaj mjesec",
	"field-weekdayOfMonth": "dan u mjesecu",
	"field-month-relative+1": "sljedeći mjesec",
	"field-week": "sedmica",
	"field-sat-short-relative+0": "ova sub.",
	"field-sat-short-relative+1": "sljedeća sub.",
	"field-year-relative+0": "ove godine",
	"field-week-relative+-1": "prošle sedmice",
	"field-year-relative+1": "sljedeće godine",
	"field-era-short": "era",
	"field-quarter-short": "kv.",
	"field-dayOfYear-narrow": "dan u g.",
	"field-sun-short-relative+-1": "prošla ned.",
	"field-thu-short-relative+-1": "prošli čet.",
	"field-tue-short-relative+-1": "prošli uto.",
	"field-mon-relative+-1": "prošli ponedjeljak",
	"field-sat-narrow-relative+-1": "prošla sub.",
	"field-month-narrow": "mj.",
	"field-week-relative+0": "ove sedmice",
	"field-sun-short-relative+0": "ova ned.",
	"field-week-relative+1": "sljedeće sedmice",
	"field-sun-short-relative+1": "sljedeća ned."
}
//end v1.x content
);
